@@ -32,4 +32,10 @@ def dump(value, path: os.PathLike):
         with open(path, 'w') as f:
             json.dump(value, f)
     else:
-        raise ValueError('path must end in either .pickle or .json.')
\ No newline at end of file
+        raise ValueError('path must end in either .pickle or .json.')
+        
+
+def chunks(lst, n):
+    """Yield successive n-sized chunks from lst."""
+    for i in range(0, len(lst), n):
+        yield lst[i:i + n]
\ No newline at end of file
